@@ -4,9 +4,9 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.2.3';
+our $VERSION = 'v2.3.1';
 
-use Perl6::Export::Attrs;
+use Export::Attrs;
 use Narada;
 use Path::Tiny 0.053;
 
@@ -14,7 +14,7 @@ use constant NARADA     => eval { local $SIG{__DIE__}; Narada::detect() } || q{}
 use constant DB_DIR     => NARADA eq 'narada-1' ? 'db' : 'mysql';
 use constant MAXPERM    => 0666; ## no critic (ProhibitLeadingZeros)
 
-my $VAR_NAME = qr{\A(?:(?![.][.]?/)[\w.-]+/)*[\w.-]+\z}xms;
+my $VAR_NAME = qr{\A(?:(?![.][.]?/)[\w.-]+/)*(?![.][.]?\z)[\w.-]+\z}xms;
 
 
 sub get_config :Export {
@@ -75,9 +75,7 @@ Narada::Config - manage project configuration
 
 =head1 VERSION
 
-This document describes Narada::Config version v2.2.3
-=head1 SYNOPSIS
-
+This document describes Narada::Config version v2.3.1
     use Narada::Config;
 
     my $version = get_config_line("version");
@@ -222,4 +220,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=cut
\ No newline at end of file
+=cut
