@@ -4,9 +4,9 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.2.3';
+our $VERSION = 'v2.3.1';
 
-use Perl6::Export::Attrs;
+use Export::Attrs;
 use Narada;
 use Fcntl qw( :DEFAULT :flock F_SETFD FD_CLOEXEC );
 use Errno;
@@ -86,9 +86,7 @@ Narada::Lock - manage project locks
 
 =head1 VERSION
 
-This document describes Narada::Lock version v2.2.3
-=head1 SYNOPSIS
-
+This document describes Narada::Lock version v2.3.1
     use Narada::Lock qw( shared_lock unlock child_inherit_lock );
     use Narada::Lock qw( exclusive_lock unlock_new unlock );
 
@@ -304,4 +302,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=cut
\ No newline at end of file
+=cut
